@@ -85,7 +85,7 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 #endif
 
 
-
+	sip_port = 5060;
 	cp = getLast("ack");
 	if(!cp)
 		cp = getLast("acktimer");
@@ -107,11 +107,17 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	if(!cp)
 		cp = getLast("interface");
 
+	if(cp && !strchr(cp, ':'))
+	{
+		sip_port = atoi(cp);
+		cp = NULL;
+	}
+
 	if(!cp)
 	{
 		gethostname(buf, sizeof(buf) - 1);
 		InetAddress host(buf);
-		snprintf(buf, sizeof(buf), "%s:5060", inet_ntoa(host.getAddress()));
+		snprintf(buf, sizeof(buf), "%s:%d", inet_ntoa(host.getAddress()), sip_port);
 		setValue("interface", buf);
 		cp = getLast("interface");
 	}
@@ -446,6 +452,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
         const char *cp = ScriptChecks::findKeyword(line, "timeout");
 	const char *lcp;
 	char buf[1024];
+	char uname[65];
 	unsigned len, pos;
 	char *p;
 	char *uri;
@@ -531,7 +538,11 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->line = line;
 	reg->scr = scr;
 
-	snprintf(buf, sizeof(buf) - 2, "sip:%s", scr->name);
+	cp = scr->name;
+	if(!strnicmp(cp, "sip::", 5))
+		cp += 5;
+
+	snprintf(buf, sizeof(buf) - 2, "sip:%s", cp);
 	p = strchr(buf + 4, ':');
 	if(p)
 	{
@@ -541,6 +552,10 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	}
 
 	len = strlen(buf);
+	setString(uname, sizeof(uname), buf + 4);
+	if(!reg->userid)
+		reg->userid = uname;
+
 	buf[len++] = '@';
 	buf[len] = 0;
 	pos = len;
