@@ -28,6 +28,13 @@ ScriptThread(interp, 0), Dir(path)
 	sym = var;
 	prefix = interp->getKeyword("match");
 	suffix = interp->getKeyword("extension");
+	after = interp->getKeyword("after");
+	save = interp->getKeysymbol("after");
+
+        if(after)
+                setString(last, sizeof(last), after);
+        else
+                last[0] = 0;
 
 	snprintf(filepath, sizeof(filepath), "%s/", path);
 	fplen = strlen(filepath); 
@@ -92,6 +99,10 @@ void ListThread::run(void)
 
 		note = NULL;
 
+		if(after)
+			if(stricmp(name, after) <= 0)
+				continue;
+
 		if(longinfo)
 		{
 			setString(filepath + fplen, sizeof(filepath) - fplen, name);
@@ -109,10 +120,20 @@ void ListThread::run(void)
 		interp->append(sym, name);
 		interp->leave();
 
+		if(stricmp(name, last) > 0)
+			setString(last, sizeof(last), name);
+
 		if(longinfo)
 			af.close();			
 	}
 
+	if(save)
+	{
+		interp->enter();
+		commit(save, last);
+		interp->leave();
+	}
+
 	exit(NULL);
 }
 
